Thank you for choosing pyfie!

Here are the (shared) methods you can use:

## compose(path: str, value)
`compose()` is a function used to create files with an encrypted value.

## parse(path: str)
`parse()` is a function used to get decrypted value of a file.
